import abc


class Base(metaclass=abc.ABCMeta):
    """
    Abstract class that needs to be derieved by every abstract
    representation of a Tk widget.
    """

    @abc.abstractmethod
    def create(self, parent, align=None):
        """
        Abstract method that handles creation of the widget.

        Keyword arguments:
        parent -- parent of the element to be put into
        align  -- alignment of the element in container tk.constants.(TOP/RIGHT/BOTTOM/LEFT)
        """
        raise NotImplementedError("`create` method not implemented")

    @abc.abstractmethod
    def destroy(self):
        """Destroys the widget"""
        raise NotImplementedError("`destroy` method not implemented")
