import tkinter as tk
import tkinter.ttk as ttk

from aui.widgets import Button
from aui_tk.widgets.Base import Base
from aui_tk import Errors


class Button(Button, Base):
    """Represents Tk button"""

    def __init__(self, text, onclick=None, **kwargs):
        """
        Keyword arguments:
        text     -- button text
                    | str
        onclick  -- function invoked after pressing the button
                    | function: Button -> void
        Arguments:
        **kwargs -- any keyword arguments that will be pased
                    additionally when creating ttk.Checkbutton
        Attributes:
        wide     -- makes the button wide
        """
        self._initial_value = text
        self._text = None
        self.callback = lambda: onclick(self) if onclick else None
        self._extra_params = kwargs
        self._button = None
        self.__wide = False

    def __make_wide(self):
        self.__wide = True

    def __getattr__(self, attr):
        functions = {
            'wide': self.__make_wide
        }

        if attr not in functions:
            raise KeyError("`{}` is not a valid button modifier".format(attr))

        functions[attr]()
        return self

    @property
    def text(self):
        """Get button's text"""
        try:
            return self._text.get()
        except:
            raise Errors.NotInitializedException("Button has not been initialized yet")

    @text.setter
    def text(self, value):
        """Set button's text"""
        try:
            self._text.set(value)
        except:
            raise Errors.NotInitializedException("Button has not been initialized yet")

    def destroy(self):
        """Destroys the button"""
        self._button.destroy()

    def create(self, parent, align=None):
        """
        Creates button and assigns it to its parent

        Keyword arguments:
        parent -- parent of the element to be put into
        align  -- alignment of the element in container tk.constants.(TOP/RIGHT/BOTTOM/LEFT)
        """
        self._text = tk.StringVar()
        self._text.set(self._initial_value)

        self._button = ttk.Button(parent,
                                  textvariable=self._text,
                                  command=self.callback,
                                  **self._extra_params)
        self._button.pack(side=align,
                          fill=tk.constants.X if self.__wide else None)
