import tkinter as tk
import tkinter.ttk as ttk

from aui.widgets import Checkbox
from aui_tk.Errors import NotInitializedException
from aui_tk.widgets.Base import Base


class Checkbox(Checkbox, Base):
    """Represents Tk checkbox with label"""

    def __init__(self, text, selected=False, onchange=None, **kwargs):
        """
        Keyword arguments:
        text     -- checkbox text
                    | str
        selected -- whether the checkbox is selected on init
                    | boolean
        onchange -- function invoked after toggling the checkbox
                    | function: Checkbox -> void
        Arguments:
        **kwargs -- any keyword arguments that will be pased
                    additionally when creating ttk.Checkbutton
        """
        self.text = text
        self._selected = selected
        self._value = None
        self._extra_params = kwargs
        self.callback = lambda: onchange(self) if onchange else None
        self._checkbox = None

    @property
    def selected(self):
        """Check if checkbox is selected"""
        try:
            return self._value.get()
        except:
            raise NotInitializedException("Checkbox has not been initialized yet")

    @selected.setter
    def selected(self, value):
        """Set checkbox (not) selected"""
        try:
            self._value.set(value)
        except:
            raise NotInitializedException("Checkbox has not been initialized yet")

    def destroy(self):
        """Destroys the checkbox"""
        pass
        self._checkbox.destroy()

    def create(self, parent, align=None):
        """
        Creates checkbox with label and assigns it to its parent

        Keyword arguments:
        parent -- parent of the element to be put into
        align  -- alignment of the element in container (UP/RIGHT/BOTTOM/LEFT)
        """
        self._value = tk.BooleanVar()
        self._value.set(self._selected)

        self._checkbox = ttk.Checkbutton(parent,
                                         text=self.text,
                                         onvalue=True,
                                         offvalue=False,
                                         variable=self._value,
                                         command=self.callback,
                                         **self._extra_params)
        self._checkbox.pack(side=align)
