import tkinter as tk
import tkinter.ttk as ttk

from aui.widgets import Label
from aui_tk.widgets.Base import Base


class Label(Label):
    """Represents Tk label"""

    def __init__(self, text, **kwargs):
        """
        Keyword arguments:
        text     -- label text
                    | str
        Arguments:
        **kwargs -- any keyword arguments that will be pased
                    additionally when creating ttk.Label
        """
        self._text = text
        self._extra_params = kwargs
        self._label = None
        self._parent = None

    @property
    def text(self):
        return self._text

    @text.setter
    def text(self, value):
        self._text = value
        self.destroy()
        self.create(self._parent)

    def destroy(self):
        """Destroys the label"""
        self._label.destroy()

    def create(self, parent, align=None):
        """
        Creates label and assigns it to its parent

        Keyword arguments:
        parent -- parent of the element to be put into
        align  -- alignment of the element in container (UP/RIGHT/BOTTOM/LEFT)
        """
        self._parent = parent

        self._label = ttk.Label(parent, text=self.text, **self._extra_params)
        self._label.pack(side=align)
