import tkinter as tk

from aui.widgets import Text
from aui_tk.widgets.Base import Base
from aui_tk import Errors


class Text(Text, Base):
    """Represents Tk Text"""

    def __init__(self, text="", **kwargs):
        """
        Keyword arguments:
        text          -- default text
                          | str (default: "")
        Arguments:
        **kwargs       -- any keyword arguments that will be pased
                          additionally when creating tk.Text
        """
        self._initial_text = text
        self._extra_params = kwargs
        self._text_field = None

    @property
    def text(self):
        """Get text's text"""
        try:
            return self._text_field.get("1.0", tk.constants.END)
        except:
            raise Errors.NotInitializedException("Text has not been initialized yet")

    @text.setter
    def text(self, new_text):
        """Set text's text"""
        try:
            self._text_field.delete("1.0", tk.constants.END)
            self._text_field.insert("1.0", new_text)
        except:
            raise Errors.NotInitializedException("Text has not been initialized yet")

    def destroy(self):
        """Destroys the text field"""
        self._text_field.destroy()

    def create(self, parent, align=None):
        """
        Creates input and assigns it to its parent

        Keyword arguments:
        parent -- parent of the element to be put into
        align  -- alignment of the element in container (UP/RIGHT/BOTTOM/LEFT)
        """
        self._text_field = tk.Text(parent, **self._extra_params)
        self._text_field.pack(side=align, fill=tk.constants.BOTH, expand=1)
