import tkinter as tk
import tkinter.ttk as ttk

from aui.widgets import Vertical
from aui_tk.widgets.Base import Base


class Vertical(Vertical, Base):
    """Vertical container - tkinter.Frame"""

    def __init__(self, *children, **kwargs):
        """
        Arguments:
        *children -- children elements of the container
        **kwargs  -- any keyword arguments that will be pased
                     additionally when creating ttk.Frame
        """
        self.__children = list(children)
        self._extra_params = kwargs
        self._vertical = None

    def create(self, parent, align=None):
        """
        Creates vertical container and assigns it to its parent

        Keyword arguments:
        parent -- parent of the element to be put into
        align  -- alignment of the element in container tk.constants.(TOP/RIGHT/BOTTOM/LEFT)
        """
        self._vertical = ttk.Frame(parent, **self._extra_params)
        self._vertical.pack(side=align, fill=tk.constants.BOTH, expand=1)
        self.__mount_children()

    def __mount_children(self):
        for child in self.__children:
            self.append(child)

    def destroy(self):
        """Destroys the vertical container"""
        self._vertical.destroy()

    def clear(self):
        for child in self.__children:
            child.destroy()

    def append(self, child):
        """
        Appends widget to the vertical container

        Keyword arguments:
        child -- the widget to be placed into the container
        """
        if self._vertical is not None:
            child.create(self._vertical, tk.constants.TOP)

        if child not in self.__children:
            self.__children.append(child)
